@@ -33,7 +33,7 @@ export GUILE_LOAD_PATH="$prefix/share/guile/site"
 
 help2man="help2man"
 
-bin1="dotlock.mailutils frm.mailutils from.mailutils mail.mailutils messages.mailutils mimeview movemail.mailutils mu popauth readmsg.mailutils sieve"
+bin1="dotlock.mailutils frm.mailutils from.mailutils mail.mailutils messages.mailutils mimeview movemail.mailutils mu-tool popauth readmsg.mailutils sieve"
 #bin1scm="sieve2scm"
 sbin8="comsatd imap4d maidag pop3d"
 libexec8=""
